aboutsummaryrefslogtreecommitdiffstats
path: root/boot/portal_vm_init.sh
diff options
context:
space:
mode:
authorChristopher Lott (cl778h) <clott@research.att.com>2017-08-25 08:45:17 -0400
committerChristopher Lott (cl778h) <clott@research.att.com>2017-08-25 08:46:43 -0400
commit2bd5fa2e5fb5571e4608d10c25608d1f5e0f74c9 (patch)
treee6c60391f5d5a9d1c4806bfa45b7bdfb3c92c1f5 /boot/portal_vm_init.sh
parent0fb5e3dba256af21c92e6f8b046b65f03d6a6b60 (diff)
Init script uses docker-compose
Also uses a directory of property files instead of a zip archive. Issue: PORTAL-52 Change-Id: I1861fc2efd0669c6fda5c74e004e389ff6a6c682 Signed-off-by: Christopher Lott (cl778h) <clott@research.att.com>
Diffstat (limited to 'boot/portal_vm_init.sh')
-rwxr-xr-xboot/portal_vm_init.sh83
1 files changed, 25 insertions, 58 deletions
diff --git a/boot/portal_vm_init.sh b/boot/portal_vm_init.sh
index e03fdedc..a6c1ba48 100755
--- a/boot/portal_vm_init.sh
+++ b/boot/portal_vm_init.sh
@@ -1,73 +1,40 @@
#!/bin/bash
# Starts docker containers for ONAP Portal
# be verbose
set -x
-# Refresh source area with start scripts
-cd /opt/portal
-git pull
-cd /opt
-
# Establish environment variables
NEXUS_USERNAME=$(cat /opt/config/nexus_username.txt)
NEXUS_PASSWD=$(cat /opt/config/nexus_password.txt)
NEXUS_DOCKER_REPO=$(cat /opt/config/nexus_docker_repo.txt)
DOCKER_IMAGE_VERSION=$(cat /opt/config/docker_version.txt)
-# Get container, image and tag names used below
-source portal/deliveries/os_settings.sh
+# Refresh configuration and scripts
+cd /opt/portal
+git pull
+cd deliveries
+
+# Get image names used below from docker-compose environment file
+source .env
-# Unpack property files
-unzip -o portal/deliveries/etc.zip -d /PROJECT/OpenSource/UbuntuEP/
-# Copy (ecomp-portal-BE-os) logback.xml for volume mapping
-mv portal/deliveries/os_logback.xml /PROJECT/OpenSource/UbuntuEP/etc/ECOMPPORTALAPP/
+# Copy property files
+ETC=/PROJECT/OpenSource/UbuntuEP/etc
+mkdir -p $ETC
+cp -r properties_rackspace/* $ETC
# Refresh images
docker login -u $NEXUS_USERNAME -p $NEXUS_PASSWD $NEXUS_DOCKER_REPO
-docker pull $NEXUS_DOCKER_REPO/openecomp/${DB_TAG_NAME}:$DOCKER_IMAGE_VERSION
-docker pull $NEXUS_DOCKER_REPO/openecomp/${EP_TAG_NAME}:$DOCKER_IMAGE_VERSION
-docker pull $NEXUS_DOCKER_REPO/openecomp/${WMS_TAG_NAME}:$DOCKER_IMAGE_VERSION
-
-# Remove lingering containers; order matters.
-docker rm -f $DB_CONT_NAME
-docker rm -f $DB_VOL_NAME
-docker rm -f $EP_CONT_NAME
-docker rm -f $WMS_CONT_NAME
-
-docker create --name $DB_VOL_NAME -v /var/lib/mysql mariadb
-docker tag $NEXUS_DOCKER_REPO/openecomp/${DB_TAG_NAME}:$DOCKER_IMAGE_VERSION $DB_IMG_NAME
-docker tag $NEXUS_DOCKER_REPO/openecomp/${EP_TAG_NAME}:$DOCKER_IMAGE_VERSION $EP_IMG_NAME
-# WMS image has no version in the registry
-docker tag $NEXUS_DOCKER_REPO/openecomp/${WMS_TAG_NAME}:$DOCKER_IMAGE_VERSION ${WMS_IMG_NAME}:latest
-
-# Recreate the named containers
-cd portal/deliveries
-echo "Starting database"
-./dbstart.sh
-echo "Delaying for database"
-sleep 10
-echo "Starting apps"
-./new_start.sh
-echo "Starting widget-ms"
-./widget_ms_start.sh
-
-sleep 180
-
-if [ ! -e /opt/config/boot.txt ]
-then
- if [ -e /opt/config/public_ip.txt ]
- then
- IP_ADDRESS=$(cat /opt/config/public_ip.txt)
- else
- IP_ADDRESS=$(ifconfig eth0 | grep "inet addr" | tr -s ' ' | cut -d' ' -f3 | cut -d':' -f2)
- fi
- # Wait until MySQL is running...
- while [[ $(netstat -vulntp |grep -i mysql | awk '{print $4}') != ":::3306" ]]
- do
- sleep 1
- done
- # no longer necessary; done at docker build time
- # mysql -u root -p'Aa123456' -h $IP_ADDRESS < /opt/portal/deliveries/Apps_Users_OnBoarding_Script.sql
- echo "yes" > /opt/config/boot.txt
-fi
+docker pull $NEXUS_DOCKER_REPO/openecomp/${DB_IMG_NAME}:$DOCKER_IMAGE_VERSION
+docker pull $NEXUS_DOCKER_REPO/openecomp/${EP_IMG_NAME}:$DOCKER_IMAGE_VERSION
+docker pull $NEXUS_DOCKER_REPO/openecomp/${WMS_IMG_NAME}:$DOCKER_IMAGE_VERSION
+
+# Tag them as expected by docker-compose file
+docker tag $NEXUS_DOCKER_REPO/openecomp/${DB_IMG_NAME}:$DOCKER_IMAGE_VERSION $DB_IMG_NAME:$PORTAL_TAG
+docker tag $NEXUS_DOCKER_REPO/openecomp/${EP_IMG_NAME}:$DOCKER_IMAGE_VERSION $EP_IMG_NAME:$PORTAL_TAG
+docker tag $NEXUS_DOCKER_REPO/openecomp/${WMS_IMG_NAME}:$DOCKER_IMAGE_VERSION $WMS_IMG_NAME:$PORTAL_TAG
+
+# docker-compose is not in /usr/bin
+/opt/docker/docker-compose down
+/opt/docker/docker-compose up -d
@@ -1,73 +1,40 @@
#!/bin/bash
-# Starts docker containers for ONAP Portal
+# Starts docker containers for ONAP Portal in Rackspace.
+# Version for Amsterdam/R1 uses docker-compose.
# be verbose
set -x